TaskHubSidecarServiceClient

Struct TaskHubSidecarServiceClient 

pub struct TaskHubSidecarServiceClient<T> { /* private fields */ }

Implementations

Source

impl TaskHubSidecarServiceClient<Channel>

pub async fn connect<D>(dst: D) -> Result<Self, Error>
where D: TryInto<Endpoint>, D::Error: Into<StdError>,

Attempt to create a new client by connecting to a given endpoint.

Source

impl<T> TaskHubSidecarServiceClient<T>
where T: GrpcService<BoxBody>, T::Error: Into<StdError>, T::ResponseBody: Body<Data = Bytes> + Send + 'static, <T::ResponseBody as Body>::Error: Into<StdError> + Send,

pub fn new(inner: T) -> Self

pub fn with_origin(inner: T, origin: Uri) -> Self

pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> TaskHubSidecarServiceClient<InterceptedService<T, F>>
where F: Interceptor, T::ResponseBody: Default, T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>, <T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,

pub fn send_compressed(self, encoding: CompressionEncoding) -> Self

Compress requests with the given encoding.

This requires the server to support it otherwise it might respond with an error.

pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self

Enable decompressing responses.

pub fn max_decoding_message_size(self, limit: usize) -> Self

Limits the maximum size of a decoded message.

Default: 4MB

pub fn max_encoding_message_size(self, limit: usize) -> Self

Limits the maximum size of an encoded message.

Default: usize::MAX

pub async fn hello( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<()>, Status>

Sends a hello request to the sidecar service.

pub async fn start_instance( &mut self, request: impl IntoRequest<CreateInstanceRequest>, ) -> Result<Response<CreateInstanceResponse>, Status>

Starts a new orchestration instance.

pub async fn get_instance( &mut self, request: impl IntoRequest<GetInstanceRequest>, ) -> Result<Response<GetInstanceResponse>, Status>

Gets the status of an existing orchestration instance.

pub async fn rewind_instance( &mut self, request: impl IntoRequest<RewindInstanceRequest>, ) -> Result<Response<RewindInstanceResponse>, Status>

Rewinds an orchestration instance to last known good state and replays from there.

pub async fn wait_for_instance_start( &mut self, request: impl IntoRequest<GetInstanceRequest>, ) -> Result<Response<GetInstanceResponse>, Status>

Waits for an orchestration instance to reach a running or completion state.

pub async fn wait_for_instance_completion( &mut self, request: impl IntoRequest<GetInstanceRequest>, ) -> Result<Response<GetInstanceResponse>, Status>

Waits for an orchestration instance to reach a completion state (completed, failed, terminated, etc.).

pub async fn raise_event( &mut self, request: impl IntoRequest<RaiseEventRequest>, ) -> Result<Response<RaiseEventResponse>, Status>

Raises an event to a running orchestration instance.

pub async fn terminate_instance( &mut self, request: impl IntoRequest<TerminateRequest>, ) -> Result<Response<TerminateResponse>, Status>

Terminates a running orchestration instance.

pub async fn suspend_instance( &mut self, request: impl IntoRequest<SuspendRequest>, ) -> Result<Response<SuspendResponse>, Status>

Suspends a running orchestration instance.

pub async fn resume_instance( &mut self, request: impl IntoRequest<ResumeRequest>, ) -> Result<Response<ResumeResponse>, Status>

Resumes a suspended orchestration instance.

pub async fn query_instances( &mut self, request: impl IntoRequest<QueryInstancesRequest>, ) -> Result<Response<QueryInstancesResponse>, Status>

pub async fn purge_instances( &mut self, request: impl IntoRequest<PurgeInstancesRequest>, ) -> Result<Response<PurgeInstancesResponse>, Status>

pub async fn get_work_items( &mut self, request: impl IntoRequest<GetWorkItemsRequest>, ) -> Result<Response<Streaming<WorkItem>>, Status>

pub async fn complete_activity_task( &mut self, request: impl IntoRequest<ActivityResponse>, ) -> Result<Response<CompleteTaskResponse>, Status>

pub async fn complete_orchestrator_task( &mut self, request: impl IntoRequest<OrchestratorResponse>, ) -> Result<Response<CompleteTaskResponse>, Status>

pub async fn complete_entity_task( &mut self, request: impl IntoRequest<EntityBatchResult>, ) -> Result<Response<CompleteTaskResponse>, Status>

pub async fn create_task_hub( &mut self, request: impl IntoRequest<CreateTaskHubRequest>, ) -> Result<Response<CreateTaskHubResponse>, Status>

Deletes and Creates the necessary resources for the orchestration service and the instance store

pub async fn delete_task_hub( &mut self, request: impl IntoRequest<DeleteTaskHubRequest>, ) -> Result<Response<DeleteTaskHubResponse>, Status>

Deletes the resources for the orchestration service and optionally the instance store

pub async fn signal_entity( &mut self, request: impl IntoRequest<SignalEntityRequest>, ) -> Result<Response<SignalEntityResponse>, Status>

sends a signal to an entity

pub async fn get_entity( &mut self, request: impl IntoRequest<GetEntityRequest>, ) -> Result<Response<GetEntityResponse>, Status>

get information about a specific entity

pub async fn query_entities( &mut self, request: impl IntoRequest<QueryEntitiesRequest>, ) -> Result<Response<QueryEntitiesResponse>, Status>

query entities

pub async fn clean_entity_storage( &mut self, request: impl IntoRequest<CleanEntityStorageRequest>, ) -> Result<Response<CleanEntityStorageResponse>, Status>

clean entity storage