pub enum EventType {
Show 20 variants
ExecutionStarted(ExecutionStartedEvent),
ExecutionCompleted(ExecutionCompletedEvent),
ExecutionTerminated(ExecutionTerminatedEvent),
TaskScheduled(TaskScheduledEvent),
TaskCompleted(TaskCompletedEvent),
TaskFailed(TaskFailedEvent),
SubOrchestrationInstanceCreated(SubOrchestrationInstanceCreatedEvent),
SubOrchestrationInstanceCompleted(SubOrchestrationInstanceCompletedEvent),
SubOrchestrationInstanceFailed(SubOrchestrationInstanceFailedEvent),
TimerCreated(TimerCreatedEvent),
TimerFired(TimerFiredEvent),
OrchestratorStarted(OrchestratorStartedEvent),
OrchestratorCompleted(OrchestratorCompletedEvent),
EventSent(EventSentEvent),
EventRaised(EventRaisedEvent),
GenericEvent(GenericEvent),
HistoryState(HistoryStateEvent),
ContinueAsNew(ContinueAsNewEvent),
ExecutionSuspended(ExecutionSuspendedEvent),
ExecutionResumed(ExecutionResumedEvent),
}Variants
ExecutionStarted(ExecutionStartedEvent)
ExecutionCompleted(ExecutionCompletedEvent)
ExecutionTerminated(ExecutionTerminatedEvent)
TaskScheduled(TaskScheduledEvent)
TaskCompleted(TaskCompletedEvent)
TaskFailed(TaskFailedEvent)
SubOrchestrationInstanceCreated(SubOrchestrationInstanceCreatedEvent)
SubOrchestrationInstanceCompleted(SubOrchestrationInstanceCompletedEvent)
SubOrchestrationInstanceFailed(SubOrchestrationInstanceFailedEvent)
TimerCreated(TimerCreatedEvent)
TimerFired(TimerFiredEvent)
OrchestratorStarted(OrchestratorStartedEvent)
OrchestratorCompleted(OrchestratorCompletedEvent)
EventSent(EventSentEvent)
EventRaised(EventRaisedEvent)
GenericEvent(GenericEvent)
HistoryState(HistoryStateEvent)
ContinueAsNew(ContinueAsNewEvent)
ExecutionSuspended(ExecutionSuspendedEvent)
ExecutionResumed(ExecutionResumedEvent)
Implementations
Sourceimpl EventType
impl EventType
Sourcepub fn merge(
field: &mut Option<EventType>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<EventType>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.