pub struct TaskHubSidecarServiceClient<T> { /* private fields */ }Implementations
Sourceimpl<T> TaskHubSidecarServiceClient<T>where
T: GrpcService<BoxBody>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> TaskHubSidecarServiceClient<T>where
T: GrpcService<BoxBody>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> TaskHubSidecarServiceClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<BoxBody>, Response = Response<<T as GrpcService<BoxBody>>::ResponseBody>>,
<T as Service<Request<BoxBody>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn hello(
&mut self,
request: impl IntoRequest<()>,
) -> Result<Response<()>, Status>
pub async fn hello( &mut self, request: impl IntoRequest<()>, ) -> Result<Response<()>, Status>
Sends a hello request to the sidecar service.
Sourcepub async fn start_instance(
&mut self,
request: impl IntoRequest<CreateInstanceRequest>,
) -> Result<Response<CreateInstanceResponse>, Status>
pub async fn start_instance( &mut self, request: impl IntoRequest<CreateInstanceRequest>, ) -> Result<Response<CreateInstanceResponse>, Status>
Starts a new orchestration instance.
Sourcepub async fn get_instance(
&mut self,
request: impl IntoRequest<GetInstanceRequest>,
) -> Result<Response<GetInstanceResponse>, Status>
pub async fn get_instance( &mut self, request: impl IntoRequest<GetInstanceRequest>, ) -> Result<Response<GetInstanceResponse>, Status>
Gets the status of an existing orchestration instance.
Sourcepub async fn rewind_instance(
&mut self,
request: impl IntoRequest<RewindInstanceRequest>,
) -> Result<Response<RewindInstanceResponse>, Status>
pub async fn rewind_instance( &mut self, request: impl IntoRequest<RewindInstanceRequest>, ) -> Result<Response<RewindInstanceResponse>, Status>
Rewinds an orchestration instance to last known good state and replays from there.
Sourcepub async fn wait_for_instance_start(
&mut self,
request: impl IntoRequest<GetInstanceRequest>,
) -> Result<Response<GetInstanceResponse>, Status>
pub async fn wait_for_instance_start( &mut self, request: impl IntoRequest<GetInstanceRequest>, ) -> Result<Response<GetInstanceResponse>, Status>
Waits for an orchestration instance to reach a running or completion state.
Sourcepub async fn wait_for_instance_completion(
&mut self,
request: impl IntoRequest<GetInstanceRequest>,
) -> Result<Response<GetInstanceResponse>, Status>
pub async fn wait_for_instance_completion( &mut self, request: impl IntoRequest<GetInstanceRequest>, ) -> Result<Response<GetInstanceResponse>, Status>
Waits for an orchestration instance to reach a completion state (completed, failed, terminated, etc.).
Sourcepub async fn raise_event(
&mut self,
request: impl IntoRequest<RaiseEventRequest>,
) -> Result<Response<RaiseEventResponse>, Status>
pub async fn raise_event( &mut self, request: impl IntoRequest<RaiseEventRequest>, ) -> Result<Response<RaiseEventResponse>, Status>
Raises an event to a running orchestration instance.
Sourcepub async fn terminate_instance(
&mut self,
request: impl IntoRequest<TerminateRequest>,
) -> Result<Response<TerminateResponse>, Status>
pub async fn terminate_instance( &mut self, request: impl IntoRequest<TerminateRequest>, ) -> Result<Response<TerminateResponse>, Status>
Terminates a running orchestration instance.
Sourcepub async fn suspend_instance(
&mut self,
request: impl IntoRequest<SuspendRequest>,
) -> Result<Response<SuspendResponse>, Status>
pub async fn suspend_instance( &mut self, request: impl IntoRequest<SuspendRequest>, ) -> Result<Response<SuspendResponse>, Status>
Suspends a running orchestration instance.
Sourcepub async fn resume_instance(
&mut self,
request: impl IntoRequest<ResumeRequest>,
) -> Result<Response<ResumeResponse>, Status>
pub async fn resume_instance( &mut self, request: impl IntoRequest<ResumeRequest>, ) -> Result<Response<ResumeResponse>, Status>
Resumes a suspended orchestration instance.
pub async fn query_instances( &mut self, request: impl IntoRequest<QueryInstancesRequest>, ) -> Result<Response<QueryInstancesResponse>, Status>
pub async fn purge_instances( &mut self, request: impl IntoRequest<PurgeInstancesRequest>, ) -> Result<Response<PurgeInstancesResponse>, Status>
pub async fn get_work_items( &mut self, request: impl IntoRequest<GetWorkItemsRequest>, ) -> Result<Response<Streaming<WorkItem>>, Status>
pub async fn complete_activity_task( &mut self, request: impl IntoRequest<ActivityResponse>, ) -> Result<Response<CompleteTaskResponse>, Status>
pub async fn complete_orchestrator_task( &mut self, request: impl IntoRequest<OrchestratorResponse>, ) -> Result<Response<CompleteTaskResponse>, Status>
pub async fn complete_entity_task( &mut self, request: impl IntoRequest<EntityBatchResult>, ) -> Result<Response<CompleteTaskResponse>, Status>
Sourcepub async fn create_task_hub(
&mut self,
request: impl IntoRequest<CreateTaskHubRequest>,
) -> Result<Response<CreateTaskHubResponse>, Status>
pub async fn create_task_hub( &mut self, request: impl IntoRequest<CreateTaskHubRequest>, ) -> Result<Response<CreateTaskHubResponse>, Status>
Deletes and Creates the necessary resources for the orchestration service and the instance store
Sourcepub async fn delete_task_hub(
&mut self,
request: impl IntoRequest<DeleteTaskHubRequest>,
) -> Result<Response<DeleteTaskHubResponse>, Status>
pub async fn delete_task_hub( &mut self, request: impl IntoRequest<DeleteTaskHubRequest>, ) -> Result<Response<DeleteTaskHubResponse>, Status>
Deletes the resources for the orchestration service and optionally the instance store
Sourcepub async fn signal_entity(
&mut self,
request: impl IntoRequest<SignalEntityRequest>,
) -> Result<Response<SignalEntityResponse>, Status>
pub async fn signal_entity( &mut self, request: impl IntoRequest<SignalEntityRequest>, ) -> Result<Response<SignalEntityResponse>, Status>
sends a signal to an entity
Sourcepub async fn get_entity(
&mut self,
request: impl IntoRequest<GetEntityRequest>,
) -> Result<Response<GetEntityResponse>, Status>
pub async fn get_entity( &mut self, request: impl IntoRequest<GetEntityRequest>, ) -> Result<Response<GetEntityResponse>, Status>
get information about a specific entity
Sourcepub async fn query_entities(
&mut self,
request: impl IntoRequest<QueryEntitiesRequest>,
) -> Result<Response<QueryEntitiesResponse>, Status>
pub async fn query_entities( &mut self, request: impl IntoRequest<QueryEntitiesRequest>, ) -> Result<Response<QueryEntitiesResponse>, Status>
query entities
Sourcepub async fn clean_entity_storage(
&mut self,
request: impl IntoRequest<CleanEntityStorageRequest>,
) -> Result<Response<CleanEntityStorageResponse>, Status>
pub async fn clean_entity_storage( &mut self, request: impl IntoRequest<CleanEntityStorageRequest>, ) -> Result<Response<CleanEntityStorageResponse>, Status>
clean entity storage