pub trait TaskHubSidecarService:
Send
+ Sync
+ 'static {
type GetWorkItemsStream: Stream<Item = Result<WorkItem, Status>> + Send + 'static;
Show 22 methods
// Required methods
fn hello<'life0, 'async_trait>(
&'life0 self,
request: Request<()>,
) -> Pin<Box<dyn Future<Output = Result<Response<()>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn start_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CreateInstanceResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<GetInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetInstanceResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn rewind_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<RewindInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<RewindInstanceResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn wait_for_instance_start<'life0, 'async_trait>(
&'life0 self,
request: Request<GetInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetInstanceResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn wait_for_instance_completion<'life0, 'async_trait>(
&'life0 self,
request: Request<GetInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetInstanceResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn raise_event<'life0, 'async_trait>(
&'life0 self,
request: Request<RaiseEventRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<RaiseEventResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn terminate_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<TerminateRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<TerminateResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn suspend_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<SuspendRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SuspendResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn resume_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<ResumeRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ResumeResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn query_instances<'life0, 'async_trait>(
&'life0 self,
request: Request<QueryInstancesRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<QueryInstancesResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn purge_instances<'life0, 'async_trait>(
&'life0 self,
request: Request<PurgeInstancesRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<PurgeInstancesResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_work_items<'life0, 'async_trait>(
&'life0 self,
request: Request<GetWorkItemsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<Self::GetWorkItemsStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn complete_activity_task<'life0, 'async_trait>(
&'life0 self,
request: Request<ActivityResponse>,
) -> Pin<Box<dyn Future<Output = Result<Response<CompleteTaskResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn complete_orchestrator_task<'life0, 'async_trait>(
&'life0 self,
request: Request<OrchestratorResponse>,
) -> Pin<Box<dyn Future<Output = Result<Response<CompleteTaskResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn complete_entity_task<'life0, 'async_trait>(
&'life0 self,
request: Request<EntityBatchResult>,
) -> Pin<Box<dyn Future<Output = Result<Response<CompleteTaskResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn create_task_hub<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateTaskHubRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CreateTaskHubResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn delete_task_hub<'life0, 'async_trait>(
&'life0 self,
request: Request<DeleteTaskHubRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<DeleteTaskHubResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn signal_entity<'life0, 'async_trait>(
&'life0 self,
request: Request<SignalEntityRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SignalEntityResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_entity<'life0, 'async_trait>(
&'life0 self,
request: Request<GetEntityRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetEntityResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn query_entities<'life0, 'async_trait>(
&'life0 self,
request: Request<QueryEntitiesRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<QueryEntitiesResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn clean_entity_storage<'life0, 'async_trait>(
&'life0 self,
request: Request<CleanEntityStorageRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CleanEntityStorageResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Generated trait containing gRPC methods that should be implemented for use with TaskHubSidecarServiceServer.
Required Associated Types
Required Methods
Sourcefn hello<'life0, 'async_trait>(
&'life0 self,
request: Request<()>,
) -> Pin<Box<dyn Future<Output = Result<Response<()>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn hello<'life0, 'async_trait>(
&'life0 self,
request: Request<()>,
) -> Pin<Box<dyn Future<Output = Result<Response<()>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sends a hello request to the sidecar service.
Sourcefn start_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CreateInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn start_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CreateInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Starts a new orchestration instance.
Sourcefn get_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<GetInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<GetInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Gets the status of an existing orchestration instance.
Sourcefn rewind_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<RewindInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<RewindInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn rewind_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<RewindInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<RewindInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Rewinds an orchestration instance to last known good state and replays from there.
Sourcefn wait_for_instance_start<'life0, 'async_trait>(
&'life0 self,
request: Request<GetInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn wait_for_instance_start<'life0, 'async_trait>(
&'life0 self,
request: Request<GetInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Waits for an orchestration instance to reach a running or completion state.
Sourcefn wait_for_instance_completion<'life0, 'async_trait>(
&'life0 self,
request: Request<GetInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn wait_for_instance_completion<'life0, 'async_trait>(
&'life0 self,
request: Request<GetInstanceRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetInstanceResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Waits for an orchestration instance to reach a completion state (completed, failed, terminated, etc.).
Sourcefn raise_event<'life0, 'async_trait>(
&'life0 self,
request: Request<RaiseEventRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<RaiseEventResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn raise_event<'life0, 'async_trait>(
&'life0 self,
request: Request<RaiseEventRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<RaiseEventResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Raises an event to a running orchestration instance.
Sourcefn terminate_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<TerminateRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<TerminateResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn terminate_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<TerminateRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<TerminateResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Terminates a running orchestration instance.
Sourcefn suspend_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<SuspendRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SuspendResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn suspend_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<SuspendRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SuspendResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Suspends a running orchestration instance.
Sourcefn resume_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<ResumeRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ResumeResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn resume_instance<'life0, 'async_trait>(
&'life0 self,
request: Request<ResumeRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<ResumeResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Resumes a suspended orchestration instance.
fn query_instances<'life0, 'async_trait>(
&'life0 self,
request: Request<QueryInstancesRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<QueryInstancesResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn purge_instances<'life0, 'async_trait>(
&'life0 self,
request: Request<PurgeInstancesRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<PurgeInstancesResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_work_items<'life0, 'async_trait>(
&'life0 self,
request: Request<GetWorkItemsRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<Self::GetWorkItemsStream>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn complete_activity_task<'life0, 'async_trait>(
&'life0 self,
request: Request<ActivityResponse>,
) -> Pin<Box<dyn Future<Output = Result<Response<CompleteTaskResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn complete_orchestrator_task<'life0, 'async_trait>(
&'life0 self,
request: Request<OrchestratorResponse>,
) -> Pin<Box<dyn Future<Output = Result<Response<CompleteTaskResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn complete_entity_task<'life0, 'async_trait>(
&'life0 self,
request: Request<EntityBatchResult>,
) -> Pin<Box<dyn Future<Output = Result<Response<CompleteTaskResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Sourcefn create_task_hub<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateTaskHubRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CreateTaskHubResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create_task_hub<'life0, 'async_trait>(
&'life0 self,
request: Request<CreateTaskHubRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CreateTaskHubResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Deletes and Creates the necessary resources for the orchestration service and the instance store
Sourcefn delete_task_hub<'life0, 'async_trait>(
&'life0 self,
request: Request<DeleteTaskHubRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<DeleteTaskHubResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_task_hub<'life0, 'async_trait>(
&'life0 self,
request: Request<DeleteTaskHubRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<DeleteTaskHubResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Deletes the resources for the orchestration service and optionally the instance store
Sourcefn signal_entity<'life0, 'async_trait>(
&'life0 self,
request: Request<SignalEntityRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SignalEntityResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn signal_entity<'life0, 'async_trait>(
&'life0 self,
request: Request<SignalEntityRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<SignalEntityResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
sends a signal to an entity
Sourcefn get_entity<'life0, 'async_trait>(
&'life0 self,
request: Request<GetEntityRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetEntityResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_entity<'life0, 'async_trait>(
&'life0 self,
request: Request<GetEntityRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<GetEntityResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
get information about a specific entity
Sourcefn query_entities<'life0, 'async_trait>(
&'life0 self,
request: Request<QueryEntitiesRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<QueryEntitiesResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn query_entities<'life0, 'async_trait>(
&'life0 self,
request: Request<QueryEntitiesRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<QueryEntitiesResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
query entities
Sourcefn clean_entity_storage<'life0, 'async_trait>(
&'life0 self,
request: Request<CleanEntityStorageRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CleanEntityStorageResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn clean_entity_storage<'life0, 'async_trait>(
&'life0 self,
request: Request<CleanEntityStorageRequest>,
) -> Pin<Box<dyn Future<Output = Result<Response<CleanEntityStorageResponse>, Status>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
clean entity storage